@@ -5,17 +5,17 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-opsworkscm",
-    "1.63.0",
+    "1.64.0",
     __name__[0:-6],
-    "aws-opsworkscm@1.63.0.jsii.tgz",
+    "aws-opsworkscm@1.64.0.jsii.tgz",
 )
 
 __all__ = [
